# pyco

[https://pyco.nl](https://pyco.nl)

Civiel Technisch ontwerpen in Python.

Jara van Veldhoven 2020-2023.

## Installatie

Je kan de bibliotheek installeren vanuit PyPi met `pip`.

    pip install pyconl

## Documenten

[pyco handleiding](https://github.com/ornor/pyco/blob/master/docs/handleiding/pyco_handleiding.md).
